summaryrefslogtreecommitdiffstats
path: root/apps
diff options
context:
space:
mode:
Diffstat (limited to 'apps')
-rw-r--r--apps/dav/lib/SystemTag/SystemTagPlugin.php6
-rw-r--r--apps/dav/lib/SystemTag/SystemTagsInUseCollection.php2
2 files changed, 4 insertions, 4 deletions
diff --git a/apps/dav/lib/SystemTag/SystemTagsInUseCollection.php b/apps/dav/lib/SystemTag/SystemTagsInUseCollection.php
index 94a86352a96..790ebee792f 100644
--- a/apps/dav/lib/SystemTag/SystemTagsInUseCollection.php
+++ b/apps/dav/lib/SystemTag/SystemTagsInUseCollection.php
@@ -42,7 +42,7 @@ class SystemTagsInUseCollection extends \Sabre\DAV\SimpleCollection {
$this->userSession = $userSession;
$this->rootFolder = $rootFolder;
$this->mediaType = $mediaType;
- $this->name = 'systemtags-current';
+ $this->name = 'systemtags-assigned';
if ($this->mediaType != '') {
$this->name .= '/' . $this->mediaType;
}
diff --git a/apps/dav/lib/SystemTag/SystemTagPlugin.php b/apps/dav/lib/SystemTag/SystemTagPlugin.php
index 52ddc7b1b40..224a7de77eb 100644
--- a/apps/dav/lib/SystemTag/SystemTagPlugin.php
+++ b/apps/dav/lib/SystemTag/SystemTagPlugin.php
@@ -244,9 +244,9 @@ class SystemTagPlugin extends \Sabre\DAV\ServerPlugin {
return;
}
- // child nodes from systemtags-current should point to normal tag endpoint
- if (preg_match('/^systemtags-current\/[0-9]+/', $propFind->getPath())) {
- $propFind->setPath(str_replace('systemtags-current/', 'systemtags/', $propFind->getPath()));
+ // child nodes from systemtags-assigned should point to normal tag endpoint
+ if (preg_match('/^systemtags-assigned\/[0-9]+/', $propFind->getPath())) {
+ $propFind->setPath(str_replace('systemtags-assigned/', 'systemtags/', $propFind->getPath()));
}
$propFind->handle(self::ID_PROPERTYNAME, function () use ($node) {